@@ -8,8 +8,8 @@
 
 #include <QTest>
 
-#include "plasma/theme.h"
 #include "plasma/svg.h"
+#include "plasma/theme.h"
 
 class ThemeTest : public QObject
 {
@@ -21,6 +21,8 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void loadSvgIcon();
+    void testThemeConfig_data();
+    void testThemeConfig();
     void testColors();
     void testCompositingChange();
 
@@ -30,4 +32,3 @@ private:
 };
 
 #endif
-
