@@ -84,18 +84,25 @@ class Units : public QObject
     // layout hints
 
     /**
-     * units.smallSpacing is the amount of spacing that should be used around smaller UI elements,
-     * for example as spacing in Columns. Internally, this size depends on the size of
-     * the default font as rendered on the screen, so it takes user-configured font size and DPI
-     * into account.
+     * This property holds the amount of spacing that should be used between smaller UI elements,
+     * such as a small icon and a label in a button.
+     * Internally, this size depends on the size of the default font as rendered on the screen,
+     * so it takes user-configured font size and DPI into account.
      */
     Q_PROPERTY(int smallSpacing READ smallSpacing NOTIFY spacingChanged)
 
     /**
-     * units.largeSpacing is the amount of spacing that should be used inside bigger UI elements,
-     * for example between an icon and the corresponding text. Internally, this size depends on
-     * the size of the default font as rendered on the screen, so it takes user-configured font
-     * size and DPI into account.
+     * This property holds the amount of spacing that should be used between medium UI elements,
+     * such as buttons and text fields in a toolbar.
+     * Internally, this size depends on the size of the default font as rendered on the screen,
+     * so it takes user-configured font size and DPI into account.
+     */
+    Q_PROPERTY(int mediumSpacing READ mediumSpacing NOTIFY spacingChanged)
+
+    /**
+     * This property is functionally identical to gridUnit. To avoid confusion, it should not be used.
+     *
+     * TODO KF6: This should be changed to work like Kirigami::Units::largeSpacing.
      */
     Q_PROPERTY(int largeSpacing READ largeSpacing NOTIFY spacingChanged)
 
@@ -199,6 +206,12 @@ public:
      */
     int smallSpacing() const;
 
+    /**
+     * @return Pixel value for medium spacing between elements.
+     * @since 5.92
+     */
+    int mediumSpacing() const;
+
     /**
      * @return Pixel value for large spacing between elements.
      * @since 5.0
@@ -286,6 +299,7 @@ private:
     static SharedAppFilter *s_sharedAppFilter;
 
     int m_smallSpacing;
+    int m_mediumSpacing;
     int m_largeSpacing;
 
     KConfigWatcher::Ptr m_animationSpeedWatcher;
