@@ -23,7 +23,7 @@
  * }
  * @endcode
  */
-class Application: public QObject
+class Application : public QObject
 {
     Q_OBJECT
 
@@ -40,7 +40,7 @@ class Application: public QObject
 
 public:
     explicit Application(QObject *parent = nullptr);
-    ~Application();
+    ~Application() override;
 
     QString application() const;
     bool running() const;
@@ -62,4 +62,3 @@ private:
 };
 
 #endif /* APPLICATION_H */
-
