@@ -10,7 +10,6 @@
 #include "private/containment_p.h"
 
 #include <KLocalizedString>
-#include <KWindowSystem>
 #include <QDebug>
 
 #include "config-plasma.h"
@@ -53,7 +52,7 @@ void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containme
 
     // adjust applet actions
     QAction *appAction = qobject_cast<QAction *>(actions->action(QStringLiteral("remove")));
-    appAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D, Qt::ALT + Qt::Key_R));
+    appAction->setShortcut(QKeySequence(Qt::ALT | Qt::Key_D, Qt::ALT | Qt::Key_R));
     if (c && c->d->isPanelContainment()) {
         appAction->setText(i18n("Remove this Panel"));
     } else {
@@ -62,7 +61,7 @@ void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containme
 
     appAction = qobject_cast<QAction *>(actions->action(QStringLiteral("configure")));
     if (appAction) {
-        appAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D, Qt::ALT + Qt::Key_S));
+        appAction->setShortcut(QKeySequence(Qt::ALT | Qt::Key_D, Qt::ALT | Qt::Key_S));
         appAction->setText(i18n("Activity Settings"));
     }
 
@@ -71,7 +70,7 @@ void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containme
     appletBrowserAction->setAutoRepeat(false);
     appletBrowserAction->setText(i18n("Add Widgets..."));
     appletBrowserAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
-    appletBrowserAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D, Qt::Key_A));
+    appletBrowserAction->setShortcut(QKeySequence(Qt::ALT | Qt::Key_D, Qt::Key_A));
     appletBrowserAction->setData(Plasma::Types::AddAction);
 }
 
@@ -97,7 +96,7 @@ void ContainmentPrivate::checkStatus(Plasma::Types::ItemStatus appletStatus)
     if (appletStatus < q->status() || appletStatus == Plasma::Types::HiddenStatus) {
         // check to see if any other applet has a higher status, and stick with that if we do
         // we'll treat HiddenStatus as lowest as we cannot change the enum value which is highest anymore
-        for (Applet *applet : qAsConst(applets)) {
+        for (Applet *applet : std::as_const(applets)) {
             if (applet->status() > appletStatus && applet->status() != Plasma::Types::HiddenStatus) {
                 appletStatus = applet->status();
             }
@@ -138,7 +137,7 @@ void ContainmentPrivate::containmentConstraintsEvent(Plasma::Types::Constraints
         }
 
         // tell the applets too
-        for (Applet *a : qAsConst(applets)) {
+        for (Applet *a : std::as_const(applets)) {
             /*Why qMin?
              * the applets immutability() is the maximum between internal applet immutability
              * and the immutability of its containment.
@@ -161,7 +160,7 @@ void ContainmentPrivate::containmentConstraintsEvent(Plasma::Types::Constraints
     }
 
     if (appletConstraints != Types::NoConstraint) {
-        for (Applet *applet : qAsConst(applets)) {
+        for (Applet *applet : std::as_const(applets)) {
             applet->updateConstraints(appletConstraints);
         }
     }
@@ -184,7 +183,7 @@ Applet *ContainmentPrivate::createApplet(const QString &name, const QVariantList
 
     if (!applet) {
         qCWarning(LOG_PLASMA) << "Applet" << name << "could not be loaded.";
-        applet = new Applet(nullptr, QString(), id);
+        applet = new Applet(nullptr, KPluginMetaData(), QVariantList{QVariant(), QVariant(), id});
         applet->setLaunchErrorMessage(i18n("Could not find requested component: %1", name));
     }
 
