@@ -1,28 +1,15 @@
 /*
- *   Copyright 2014 by Aleix Pol Gonzalez <aleixpol@blue-systems.com>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef TIMETRACKER_H
 #define TIMETRACKER_H
 
+#include <QDateTime>
 #include <QObject>
 #include <QVariantMap>
-#include <QDateTime>
 #include <QVector>
 
 #include "plasma/plasma_export.h"
@@ -32,14 +19,12 @@ namespace Plasma
 class Containment;
 class Applet;
 
-struct TimeEvent
-{
+struct TimeEvent {
     QDateTime moment;
     QString comment;
 };
 
-struct ObjectHistory
-{
+struct ObjectHistory {
     QVariantMap initial;
     QVector<TimeEvent> events;
 };
@@ -56,12 +41,12 @@ struct ObjectHistory
  * as the process has quit.
  */
 
-class PLASMA_EXPORT TimeTracker : QObject
+class PLASMA_EXPORT TimeTracker : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    explicit TimeTracker(QObject* applet);
-    virtual ~TimeTracker();
+    explicit TimeTracker(QObject *applet);
+    ~TimeTracker() override;
 
 private Q_SLOTS:
     void init();
